#!/usr/bin/perl

# Description: A shell script to reorder voicemail sound and information files.
#              This script is intended to be called from F::Voicemail::delete_voicemail() every time
#              a voicemail is deleted.
#              Example:
#                  vm_reorder.pl /var/spool/asterisk/voicemail/default/7000/INBOX

use strict;
use File::Spec;

unless (@ARGV && @ARGV == 1) {
	die "usage: $0 <path>\n";
}

my $path = shift @ARGV;

print "$0: Processing files in $path\n";

foreach my $type (qw/wav WAV gsm txt/) {
	reorder($type);
}

sub reorder {
	my $type = shift;
	
	my @files = sort glob "$path/*.$type";
	unless (@files) {
		print "$0: $type: nothing to do\n";
		return;
	}
	
	@files = map {
		my ($volume,$directories,$file) = File::Spec->splitpath( $_ );
		$file;
	} @files;

	print "$0: $type:\n";
	print "$0: Total files: ", scalar @files, "\n";
	print "$0: First file: $files[0]\n";
	print "$0: Last file: $files[-1]\n";
	
	my $count = 0;
	foreach my $oldname (@files) {
		my $newname = 'msg' . sprintf('%04d', $count++) . ".$type";
		
		print "$0: $oldname -> $newname ";
		if (rename "$path/$oldname", "$path/$newname") {
			print 'OK';
		} else {
			print 'Failed';
		}
		print "\n";
	}
}
